# -*- coding: utf-8 -*-
import argparse
import datetime
import sys

sys.path.append('MyModules')
import ReadData
import RF_Simulation

__version__ = '200119A'

parser = argparse.ArgumentParser(description='calculation of accelerating cell by SUPERFISH')
parser.add_argument('input', help='input file')
parser.add_argument('-v', '--version', action='version',\
                        version=__version__,\
                        help='show version and exit')
args = parser.parse_args()


# ----- インプットファイルの読み込み -----
acc = ReadData.Input(args.input)
indat = acc.get_input_datas()

# ----- SUPERFISH の計算 -----
title = indat['conditions']['title']
dx    = indat['conditions']['dx']
freq  = indat['conditions']['freq']
cell  = indat['cell']
is_disp = indat['conditions']['is_disp']
is_GPT  = indat['conditions']['is_GPT']
if is_GPT:
    GPT   = indat['GPT']
else:
    GPT = False

superfish = RF_Simulation.SUPERFISH(title, dx, freq, cell, GPT)
superfish.all_cell_2b_tune()
superfish.all_cell_parameter_calculation(is_disp, is_GPT)

# ----- GPT 計算用の gdf ファイルの作成と入力 (*.in) の作成 -----
if is_GPT:
    # ----- カップラーの定在波領域 -----
    superfish.init_SW_region()
    superfish.mk_sw_region()
    # ----- GPT 入力 (*.in) の作成 -----
    superfish.GPT_in_init()
    superfish.set_cell_para()
    superfish.set_sw_para()
    superfish.write_gpt_input_SW(cpl='in')
    superfish.write_gpt_input_TW()
    superfish.write_gpt_input_SW(cpl='out')
    superfish.mk_cell_z_phase_file()
    
superfish.mk_report(args.input)
